@@ -14,4 +14,5 @@ struct GFC {
 
 GFC* gfc_init(uint64_t range, uint64_t rounds, uint64_t seed);
 void gfc_destroy(GFC* gfc);
-uint64_t gfc_encrypt(GFC* gfc, uint64_t m);
+uint64_t gfc_decrypt(const GFC* gfc, uint64_t m);
+uint64_t gfc_encrypt(const GFC* gfc, uint64_t m);
